=============================================
How should I cite xeofs?
=============================================

.. note::
    
    Always cite the original publication/reference for the methods you use. xeofs is an easy-to-use interface but should not replace the acknowledgment of the original research.


We appreciate your willingness to reference xeofs in your academic work. If you're using xeofs, we recommend citing both the following:


1. The xeofs overview article published in the Journal of Open Research Software:

    Rieger, N. & Levang, S. J. (2024). xeofs: Comprehensive EOF analysis in Python with xarray. Journal of Open Source Software, 9(93), 6060. DOI: https://doi.org/10.21105/joss.06060

   Here's an example of a BibTeX entry::

        @article{xeofs_development_team,
          title     = {xeofs: Comprehensive EOF analysis in Python with xarray},
          author    = {Rieger, N. and Levang, S. J.},
          journal   = {Journal of Open Source Software},
          volume    = {9},
          number    = {93},
          year      = {2024},
          publisher = {The Open Journal},
          doi       = {10.21105/joss.06060},
          url       = {https://doi.org/10.21105/joss.06060}
        }



2. Additionally, you may cite the specific version of the xeofs package you're using. You can obtain a Zenodo citation and DOI for this purpose here:

    .. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.6323012.svg
      :target: https://doi.org/10.5281/zenodo.10897729
    
   Here's an example of a BibTeX entry::
    
        @misc{xeofs_v2_3_2,
            author = {Rieger, N. and Levang, S. J. and others},
            title  = {xeofs: v2.3.2},
            month  = mar,
            year   = 2024,
            doi    = {10.5281/zenodo.10897729},
            url    = {https://doi.org/10.5281/zenodo.10897729}
        }